searchData={"content_type":"text/markdown","items":[{"doc":"`OpentelemetryProcessPropagator` provides helpers for dealing\nwith context propagation across process boundaries.","ref":"OpentelemetryProcessPropagator.html","title":"OpentelemetryProcessPropagator","type":"module"},{"doc":"Erlang and Elixir do not have a mechanism for transparently passing\ncontext between processes. This requires the user to explicitly\npass data between processes. In order to continue a trace across\nprocesses, the user must start a new span and pass it to the\nspawned process.\n\n```\nspan_ctx = OpenTelemetry.Tracer.start_span(\"child\")\nctx = OpenTelemetry.Ctx.get_current()\n\ntask =\n  Task.async(fn ->\n    OpenTelemetry.Ctx.attach(ctx)\n    OpenTelemetry.Tracer.set_current_span(span_ctx)\n    # do work here\n\n    OpenTelemetry.Tracer.end_span(span_ctx)\n  end)\n\n_result = Task.await(task)\n```\n\n#","ref":"OpentelemetryProcessPropagator.html#module-context-propagation","title":"Context Propagation - OpentelemetryProcessPropagator","type":"module"},{"doc":"It's not always possible to have full control over traces, such as\nwhen using `telemetry` events emitted from a library you don't control\nto create a span. In such cases, a mechanism to fetch a context from a\ncalling process is necessary. This is effectively context propagation\nin reverse.\n\nAs an example, Ecto uses the `Task` module to execute preloads which are\neach a separate query. Since a task is a spawned process, creating an otel\nspan results in orphan spans. To correctly connect these spans we must\nfind the otel context which spawned the process.","ref":"OpentelemetryProcessPropagator.html#module-reverse-propagation","title":"Reverse Propagation - OpentelemetryProcessPropagator","type":"module"},{"doc":"Example of using `fetch_parent_ctx/1` to find a parent context.\n\n```elixir\nOpenTelemetry.with_span :span_started_in_your_app do\n  # some span being created in a process spawned by a library\n  # you don't control, e.g. Ecto preloads\n\n  Task.async(fn ->\n    parent_ctx = OpentelemetryProcessPropagator.fetch_parent_ctx(1, :\"$callers\")\n\n    OpenTelemetry.Ctx.attach(parent_ctx)\n\n    attrs = %{some_attr: :from_telemetry_event}\n\n    span =\n      OpenTelemetry.Tracer.start_span(:span_created_in_lib, %{attributes: attrs})\n\n    OpenTelemetry.Span.end_span(span)\n  end)\nend\n```\n\n```erlang\n?with_span(span_started_in_your_app, , fun() ->\n  %% some span being created in a process spawned by a library\n  %% you don't control\n\n  proc_lib:spawn_link(fun() ->\n    Tracer = opentelemetry:get_tracer(test_tracer),\n    ParentCtx = opentelemetry_process_propagator:fetch_parent_ctx(),\n    otel_ctx:attach(ParentCtx),\n    Span = otel_tracer:start_span(Tracer, span_created_in_lib, ),\n    otel_tracer:end_span(Span).\n  ).\nend\n```","ref":"OpentelemetryProcessPropagator.html#module-usage","title":"Usage - OpentelemetryProcessPropagator","type":"module"},{"doc":"Attempt to fetch an otel context from a given pid.","ref":"OpentelemetryProcessPropagator.html#fetch_ctx/1","title":"OpentelemetryProcessPropagator.fetch_ctx/1","type":"function"},{"doc":"Attempt to find an otel context in the spawning process.\n\nThis is equivalent to calling `fetch_parent_ctx(1, :\"$ancestors\")`","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/0","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/0","type":"function"},{"doc":"Attempt to find an otel context in a spawning process within `n` number of parent\nprocesses.","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/1","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/1","type":"function"},{"doc":"Attempt to find an otel context under a given process dictionary key\nwithin `n` number of parent processes. The first context found will be\nreturned.\n\nProcesses spawned by `proc_lib` are stored under `:\"$ancestors`. The\nElixir `Task` module uses the `:\"$callers` key.","ref":"OpentelemetryProcessPropagator.html#fetch_parent_ctx/2","title":"OpentelemetryProcessPropagator.fetch_parent_ctx/2","type":"function"},{"doc":"`OpentelemetryProcessPropagator.Task` provides a set of extensions\nto the `Task` module to reduce some boilerplate in propagating OpenTelemetry\ncontexts across process boundaries. Since these are extensions rather\nthan a replacement of Elixir's module, this library can be aliased\ninto a file without concern for creating spans where you do not want them.\n\nEach `Task` function is replicated with two variants: `*_with_span`\nand `*_with_linked_span`. Each of these variations has a specific use case.\nThe original implementation for each function automatically propagates the\ncurrent context.\n\n* `*` - propagates the current context\n* `*_with_span` - propagates the current context and starts a new child span.\n* `*_with_linked_span` - propagates the current context and starts a new linked span.\n\n> ##","ref":"OpentelemetryProcessPropagator.Task.html","title":"OpentelemetryProcessPropagator.Task","type":"module"},{"doc":">\n> This module does not redefine the `Task` module, instead providing a wrapper of the module,\n> so this functionality will not globally modify the default behavior of the `Task` module.","ref":"OpentelemetryProcessPropagator.Task.html#module-module-redefinement-info","title":"Module Redefinement {: .info} - OpentelemetryProcessPropagator.Task","type":"module"},{"doc":"```\ndefmodule MyApp do\n  require OpenTelemetry.Tracer\n  alias OpentelemetryProcessPropagator.Task\n\n  def traced_task_with_existing_span do\n    Task.async(fn ->\n      :ok\n    end)\n    |> Task.await()\n  end\n\n  def traced_task_with_new_span do\n    Task.async_with_span(:span_name, %{attributes: %{a: \"b\"}}, fn ->\n      Tracer.set_attribute(:c, \"d\")\n      :ok\n    end)\n    |> Task.await()\n  end\n\n  def traced_task_with_new_linked_span do\n    Task.async_with_linked_span(:span_name, %{attributes: %{a: \"b\"}}, fn ->\n      Tracer.set_attribute(:c, \"d\")\n      :ok\n    end)\n    |> Task.await()\n  end\nend\n```","ref":"OpentelemetryProcessPropagator.Task.html#module-usage","title":"Usage - OpentelemetryProcessPropagator.Task","type":"module"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.async/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async/1","title":"OpentelemetryProcessPropagator.Task.async/1","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async/3","title":"OpentelemetryProcessPropagator.Task.async/3","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with the current `t:OpenTelemetry.Ctx.t/0`\nattached.\n\nSee `Task.async_stream/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream/3","title":"OpentelemetryProcessPropagator.Task.async_stream/3","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with the\ncurrent `t:OpenTelemetry.Ctx.t/0` attached.\n\nSee `Task.async_stream/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream/5","title":"OpentelemetryProcessPropagator.Task.async_stream/5","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new linked span.\n\nSee `Task.async_stream/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.async_stream_with_linked_span/5","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new linked span.\n\nSee `Task.async_stream/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.async_stream_with_linked_span/7","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new child span.\n\nSee `Task.async_stream/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_span/5","title":"OpentelemetryProcessPropagator.Task.async_stream_with_span/5","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new child span.\n\nSee `Task.async_stream/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_stream_with_span/7","title":"OpentelemetryProcessPropagator.Task.async_stream_with_span/7","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.async/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.async_with_linked_span/3","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.async_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.async/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_span/3","title":"OpentelemetryProcessPropagator.Task.async_with_span/3","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#async_with_span/5","title":"OpentelemetryProcessPropagator.Task.async_with_span/5","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#await/1","title":"OpentelemetryProcessPropagator.Task.await/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#await/2","title":"OpentelemetryProcessPropagator.Task.await/2","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#await_many/1","title":"OpentelemetryProcessPropagator.Task.await_many/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#await_many/2","title":"OpentelemetryProcessPropagator.Task.await_many/2","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#child_spec/1","title":"OpentelemetryProcessPropagator.Task.child_spec/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#completed/1","title":"OpentelemetryProcessPropagator.Task.completed/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#ignore/1","title":"OpentelemetryProcessPropagator.Task.ignore/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#shutdown/1","title":"OpentelemetryProcessPropagator.Task.shutdown/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#shutdown/2","title":"OpentelemetryProcessPropagator.Task.shutdown/2","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0`.\n\nSee `Task.start/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start/1","title":"OpentelemetryProcessPropagator.Task.start/1","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0`.\n\nSee `Task.start/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start/3","title":"OpentelemetryProcessPropagator.Task.start/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given `fun`\nwith the current `t:OpenTelemetry.Ctx.t/0` attached.\n\nSee `Task.start_link/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link/1","title":"OpentelemetryProcessPropagator.Task.start_link/1","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given\n`module`, `function`, and `args` with the current `t:OpenTelemetry.Ctx.t/0`\nattached.\n\nSee `Task.start_link/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link/3","title":"OpentelemetryProcessPropagator.Task.start_link/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given `fun`\nin a new linked span.\n\nSee `Task.start_link/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.start_link_with_linked_span/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given\n`module`, `function`, and `args` in a new linked span.\n\nSee `Task.start_link/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.start_link_with_linked_span/5","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given `fun`\nin a new child span.\n\nSee `Task.start_link/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_span/3","title":"OpentelemetryProcessPropagator.Task.start_link_with_span/3","type":"function"},{"doc":"Starts a task as part of a supervision tree with the given\n`module`, `function`, and `args` in a new child span.\n\nSee `Task.start_link/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_link_with_span/5","title":"OpentelemetryProcessPropagator.Task.start_link_with_span/5","type":"function"},{"doc":"Starts a task with a new linked span.\n\nSee `Task.start/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_linked_span/3","title":"OpentelemetryProcessPropagator.Task.start_with_linked_span/3","type":"function"},{"doc":"Starts a task with a new linked span.\n\nSee `Task.start/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.start_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new child span.\n\nSee `Task.start/1` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_span/3","title":"OpentelemetryProcessPropagator.Task.start_with_span/3","type":"function"},{"doc":"Starts a task with a new child span.\n\nSee `Task.start/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.html#start_with_span/5","title":"OpentelemetryProcessPropagator.Task.start_with_span/5","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#yield/1","title":"OpentelemetryProcessPropagator.Task.yield/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#yield/2","title":"OpentelemetryProcessPropagator.Task.yield/2","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#yield_many/1","title":"OpentelemetryProcessPropagator.Task.yield_many/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.html#yield_many/2","title":"OpentelemetryProcessPropagator.Task.yield_many/2","type":"function"},{"doc":"`OpentelemetryProcessPropagator.Task.Supervisor` provides a set of extensions\nto the `Task.Supervisor` module to reduce some boilerplate in propagating OpenTelemetry\ncontexts across process boundaries. Since these are extensions rather\nthan a replacement of Elixir's module, this library can be aliased\ninto a file without concern for creating spans where you do not want them.\n\nEach `Task.Supervisor` function is replicated with two variants: `*_with_span`\nand `*_with_linked_span`. Each of these variations has a specific use case.\nThe original implementation for each function automatically propagates the\ncurrent context.\n\n* `*` - propagates the current context\n* `*_with_span` - propagates the current context and starts a new child span.\n* `*_with_linked_span` - propagates the current context and starts a new linked span.\n\n> ##","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html","title":"OpentelemetryProcessPropagator.Task.Supervisor","type":"module"},{"doc":">\n> This module does not redefine the `Task.Supervisor` module, instead providing a wrapper of the module,\n> so this functionality will not globally modify the default behavior of the `Task` module.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#module-module-redefinement-info","title":"Module Redefinement {: .info} - OpentelemetryProcessPropagator.Task.Supervisor","type":"module"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.Supervisor.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.async/3","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.Supervisor.async/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async/5","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink/3","type":"function"},{"doc":"Starts a task with the current `t:OpenTelemetry.Ctx.t/0` that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_linked_span/7","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.Supervisor.async_nolink/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_nolink_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_nolink_with_span/7","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with the current `t:OpenTelemetry.Ctx.t/0`\nattached.\n\nSee `Task.Supervisor.async_stream/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream/4","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream/4","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with the\ncurrent `t:OpenTelemetry.Ctx.t/0` attached.\n\nSee `Task.Supervisor.async_stream/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream/6","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with the current `t:OpenTelemetry.Ctx.t/0`\nattached.\n\nSee `Task.Supervisor.async_stream_nolink/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink/4","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink/4","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with the\ncurrent `t:OpenTelemetry.Ctx.t/0` attached.\n\nSee `Task.Supervisor.async_stream_nolink/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink/6","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new linked span.\n\nSee `Task.Supervisor.async_stream_nolink/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_linked_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_linked_span/6","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new linked span.\n\nSee `Task.Supervisor.async_stream_nolink/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_linked_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_linked_span/8","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new child span.\n\nSee `Task.Supervisor.async_stream_nolink/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_span/6","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new child span.\n\nSee `Task.Supervisor.async_stream_nolink/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_nolink_with_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_nolink_with_span/8","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new linked span.\n\nSee `Task.Supervisor.async_stream/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_linked_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_linked_span/6","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new linked span.\n\nSee `Task.Supervisor.async_stream/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_linked_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_linked_span/8","type":"function"},{"doc":"Returns a stream that runs the given function `fun` concurrently\non each element in `enumerable` with a new child span.\n\nSee `Task.Supervisor.async_stream/4` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_span/6","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_span/6","type":"function"},{"doc":"Returns a stream where the given function (`module` and `function`)\nis mapped concurrently on each element in `enumerable` with a new child span.\n\nSee `Task.Supervisor.async_stream/6` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_stream_with_span/8","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_stream_with_span/8","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.Supervisor.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_linked_span/5","type":"function"},{"doc":"Starts a task with a new linked span that can be awaited on.\n\nSee `Task.Supervisor.async/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_linked_span/7","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.Supervisor.async/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_span/5","type":"function"},{"doc":"Starts a task with a new child span that can be awaited on.\n\nSee `Task.Supervisor.async/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#async_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.async_with_span/7","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#children/1","title":"OpentelemetryProcessPropagator.Task.Supervisor.children/1","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` with the\ncurrent `t:OpenTelemetry.Ctx.t/0`.\n\nSee `Task.Supervisor.start_child/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child/3","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child/3","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` with the\ncurrent `t:OpenTelemetry.Ctx.t/0`.\n\nSee `Task.Supervisor.start_child/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child/5","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` in a new linked span.\n\nSee `Task.Supervisor.start_child/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_linked_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_linked_span/5","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` in a new linked span.\n\nSee `Task.Supervisor.start_child/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_linked_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_linked_span/7","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` in a new child span.\n\nSee `Task.Supervisor.start_child/3` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_span/5","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_span/5","type":"function"},{"doc":"Starts a task as a child of the given `supervisor` in a new child span.\n\nSee `Task.Supervisor.start_child/5` for more information.","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_child_with_span/7","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_child_with_span/7","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#start_link/1","title":"OpentelemetryProcessPropagator.Task.Supervisor.start_link/1","type":"function"},{"doc":"","ref":"OpentelemetryProcessPropagator.Task.Supervisor.html#terminate_child/2","title":"OpentelemetryProcessPropagator.Task.Supervisor.terminate_child/2","type":"function"}]}